SmartReviewConditions class

A simple class to hold the conditions for showing a review.

Constructors

SmartReviewConditions({int minAppOpens = 5, int minDaysSinceInstall = 3})

Properties

hashCode int
The hash code for this object.
no setterinherited
minAppOpens int
The minimum number of times the app must be opened.
final
minDaysSinceInstall int
The minimum number of days that must pass since first install.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited